Clazz.declarePackage("javajs.api");
Clazz.load(["java.util.zip.ZipInputStream", "javajs.api.ZInputStream"], "javajs.api.GenericZipInputStream", null, function(){
var c$ = Clazz.declareType(javajs.api, "GenericZipInputStream", java.util.zip.ZipInputStream, javajs.api.ZInputStream);
});
;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
